## v4.0.10 (2023-10-13)

## v4.0.9 (2023-10-13)

## v4.0.8 (2023-10-12)

## v4.0.7 (2023-06-17)

### Refactor

- moved all command line functions into main and improved docs

## v4.0.6 (2023-02-13)

### Refactor

- small refactors

## v4.0.5 (2023-01-16)

## v4.0.4 (2023-01-08)

## v4.0.3 (2022-10-29)

### Fix

- pylinted

## v4.0.2 (2022-10-29)

### Fix

- fixed pyproject to correctly find VERSION file for sdist

## v4.0.1 (2022-10-29)

### Fix

- **pyproject.toml**: fixed dependencies in pyproject.toml

## v4.0.0 (2022-10-29)

### Fix

- worked out all changes supporting breaking change in toolbox_utils

### Refactor

- convert to toolbox_utils.tsutils and complete pyproject.toml

## v3.4.1 (2022-07-02)

### Fix

- allow for man different approaches to specify labels

### Refactor

- removed __future__
- moved to f strings

## v3.4.0 (2022-02-14)

## v3.3.5 (2021-11-12)

### Fix

- **extract**: fixed processing of label strings

## v3.3.4 (2021-10-14)

### Fix

- corrected processing of multiple labels

## v3.3.3 (2021-08-01)

### Refactor

- moved docs to the standard docs

### Fix

- corrected tupleSearch which stopped working.

## v3.3.2 (2021-06-29)

### Refactor

- .pre-commit-config.yaml

## v3.2.2 (2021-03-14)

## v3.1.2 (2020-06-08)

### Fix

- Change away from deprecated pandas feature.

## v3.1.1 (2020-04-30)

## v2.7.12.10 (2019-09-17)

## v2.6.9.10 (2019-08-23)

## v2.5.9.10 (2019-08-23)
